@@ -354,7 +354,7 @@ def install_app(project_name, settings_path=None, **settings_patches):
         abort('No port number!?')
         return
     # edit ini
-    uwsgi_path = os.path.join(project_source_path(project_name), 'uwsgi.ini')
+    uwsgi_path = project_uwsgi_path(project_name)
     config = ConfigParser.ConfigParser()
     if os.path.exists(uwsgi_path):
         config.read(uwsgi_path)
